import configureUseSearchParam from 'configure-use-search-param';

export * from 'configure-use-search-param/param-translation-utils';

const {history, location, URL} = window;

const _getCurrentUrl = () => new URL(location.toString());
const getSearchParam = key => {
  const url = _getCurrentUrl();
  return url.searchParams.get(key);
};
const setSearchParam = (key, value) => {
  const url = _getCurrentUrl();
  if (value === undefined) {
    url.searchParams.delete(key);
  } else {
    url.searchParams.set(key, value);
  }
  history.pushState({}, '', url.toString());
  return value;
};
const onSearchParamChange = handleChange => {
  ['pushState', 'replaceState'].forEach(methodName => {
    const original = history[methodName];
    history[methodName] = function (...args) {
      const result = original.apply(this, args);
      handleChange();
      return result;
    };
  });
};

const useBrowserSearchParam = configureUseSearchParam({
  get: getSearchParam,
  set: setSearchParam,
  onChange: onSearchParamChange
});

export default useBrowserSearchParam;
